@@ -79,26 +79,21 @@ Logger <- R6::R6Class(
       if (!is.null(db_table)) {
         private$db_table <- id(db_table, log_conn)
       }
-      private$timestamp <- timestamp
 
-      # Store console log information
+      # Store the inputs
       private$.output_to_console <- output_to_console
+      private$log_conn <- log_conn
+      private$.log_path <- log_path
+      private$.start_time <- start_time
 
       # Store database log information
       if (!is.null(log_table_id)) {
         private$log_table_id <- id(log_table_id, log_conn)
         private$.log_tbl <- create_logs_if_missing(log_conn, private$log_table_id)
       }
-      private$log_conn <- log_conn
 
-      # Store file log information
-      private$.log_path <- log_path
-
-      # Store Logger information
-      private$.start_time <- start_time
-
-      # Create a line in log database for Logger
-      private$generate_db_entry()
+      # Set the timestamp (also updates paths and log db targets)
+      if (!is.null(timestamp)) self$set_timestamp(timestamp)
 
       # Warn if no logging will be done
       if (warn && is.null(self$log_path) && is.null(self$log_tbl)) {
@@ -110,6 +105,32 @@ Logger <- R6::R6Class(
       }
     },
 
+    #' @description
+    #'   Update the timestamp being logged
+    #' @param timestamp (`POSIXct(1)`, `Date(1)`, or `character(1)`)\cr
+    #'   A timestamp describing the data being processed (not the current time).
+    set_timestamp = function(timestamp) {
+      if (is.null(timestamp)) {
+        return()
+      }
+
+      # Return early if that timestamp is already set
+      if (identical(private$timestamp, timestamp)) {
+        return()
+      }
+
+      private$timestamp <- timestamp
+
+      # Changing the timestamp invalidates the filename
+      private$.log_filename <- NULL
+
+      # .. and set the log entry as not finalized
+      private$finalized <- FALSE
+
+      # Create a line in log database for Loggers current state
+      private$generate_db_entry()
+    },
+
 
     #' @description
     #'   Write a line to log (console / file).
