@@ -31,7 +31,7 @@ for (conn in get_test_conns()) {
   # Start with some clean up
   purrr::walk(c("test.mtcars", "__mtcars", "__mtcars_historical", "test.mtcars_modified", "mtcars_modified",
                 "test.SCDB_logs", "test.SCDB_logger", "test.SCDB_tmp1", "test.SCDB_tmp2", "test.SCDB_tmp3",
-                "test.SCDB_t0", "test.SCDB_t1", "test.SCDB_t2"),
+                "test.SCDB_t0", "test.SCDB_t1", "test.SCDB_t2", "test.SCDB_t3", "test.SCDB_t4"),
               ~ if (DBI::dbExistsTable(conn, id(., conn))) DBI::dbRemoveTable(conn, id(., conn)))
 
   purrr::walk(c(DBI::Id(schema = "test", table = "one.two"), DBI::Id(schema = "test.one", table = "two")),
