@@ -22,7 +22,6 @@ test_that("update_snapshot() can handle first snapshot", {
 
     logger <- Logger$new(
       db_table = db_table,
-      timestamp = timestamp,
       log_path = log_path,
       log_table_id = "test.SCDB_logs",
       log_conn = conn,
@@ -117,7 +116,6 @@ test_that("update_snapshot() can add a new snapshot", {
 
     logger <- Logger$new(
       db_table = db_table,
-      timestamp = timestamp,
       log_path = NULL,
       log_table_id = "test.SCDB_logs",
       log_conn = conn,
@@ -187,7 +185,6 @@ test_that("update_snapshot() can update a snapshot on an existing date", {
 
     logger <- Logger$new(
       db_table = db_table,
-      timestamp = timestamp,
       log_path = NULL,
       log_table_id = "test.SCDB_logs",
       log_conn = conn,
@@ -294,6 +291,60 @@ test_that("update_snapshot() can insert a snapshot between existing dates", {
   }
 })
 
+test_that("update_snapshot() correctly deactivates records", {
+  for (conn in get_test_conns()) {
+
+    # In this test we have a single value that flips back and forth, trying
+    # to confuse SCDB
+
+    if (DBI::dbExistsTable(conn, id("test.SCDB_tmp1", conn))) DBI::dbRemoveTable(conn, id("test.SCDB_tmp1", conn))
+    expect_false(table_exists(conn, "test.SCDB_tmp1"))
+
+
+    # Create test data for the test
+    t0 <- data.frame(col1 = "A", col2 = 2)
+    t1 <- data.frame(col1 = "A", col2 = 1)
+    t2 <- data.frame(col1 = "A", col2 = 2)
+    t3 <- data.frame(col1 = "A", col2 = 1)
+    t4 <- data.frame(col1 = "A", col2 = 2)
+
+    # Copy t0, t1, and t2 to conn
+    t0 <- dplyr::copy_to(conn, t0, name = id("test.SCDB_t0", conn), overwrite = TRUE, temporary = FALSE)
+    t1 <- dplyr::copy_to(conn, t1, name = id("test.SCDB_t1", conn), overwrite = TRUE, temporary = FALSE)
+    t2 <- dplyr::copy_to(conn, t2, name = id("test.SCDB_t2", conn), overwrite = TRUE, temporary = FALSE)
+    t3 <- dplyr::copy_to(conn, t3, name = id("test.SCDB_t3", conn), overwrite = TRUE, temporary = FALSE)
+    t4 <- dplyr::copy_to(conn, t4, name = id("test.SCDB_t4", conn), overwrite = TRUE, temporary = FALSE)
+
+    logger <- LoggerNull$new()
+    update_snapshot(t0, conn, "test.SCDB_tmp1", "2000-01-01", logger = logger)
+    update_snapshot(t1, conn, "test.SCDB_tmp1", "2010-01-01", logger = logger)
+    update_snapshot(t2, conn, "test.SCDB_tmp1", "2020-01-01", logger = logger)
+    update_snapshot(t3, conn, "test.SCDB_tmp1", "2030-01-01", logger = logger)
+    update_snapshot(t4, conn, "test.SCDB_tmp1", "2040-01-01", logger = logger)
+
+    t <- get_table(conn, "test.SCDB_tmp1", slice_ts = NULL) %>%
+      dplyr::arrange(.data$from_ts) %>%
+      dplyr::collect()
+
+    # If the updates have been applied correctly, the until_ts values should
+    # be the previous from_ts
+    expect_identical(
+      t$from_ts[2:5],
+      t$until_ts[1:4]
+    )
+
+    # Ensure data is the same
+    expect_identical(
+      dplyr::select(t, c("col1", "col2")),
+      tibble::tibble(
+        "col1" = rep("A", 5),
+        "col2" = c(2, 1, 2, 1, 2)
+      )
+    )
+
+    close_connection(conn)
+  }
+})
 
 
 test_that("update_snapshot() works (holistic test 1)", {
@@ -437,23 +488,20 @@ test_that("update_snapshot() handles 'NULL' updates", {
     # This is a simple update where 23 rows are replaced with 23 new ones on the given date
     db_table <- "test.SCDB_tmp1"
 
-    create_logger <- function(timestamp) {
-      Logger$new(
-        db_table = db_table,
-        timestamp = timestamp,
-        log_path = NULL,
-        log_table_id = "test.SCDB_logs",
-        log_conn = conn,
-        output_to_console = FALSE
-      )
-    }
+    logger <- Logger$new(
+      db_table = db_table,
+      log_path = NULL,
+      log_table_id = "test.SCDB_logs",
+      log_conn = conn,
+      output_to_console = FALSE
+    )
 
     # Update the table with update_snapshot() and store the results
-    update_snapshot(.data, conn, db_table, "2022-10-03 09:00:00", logger = create_logger("2022-10-03 09:00:00"))
+    update_snapshot(.data, conn, db_table, "2022-10-03 09:00:00", logger = logger)
     target_data_1 <- get_table(conn, db_table, slice_ts = NULL) %>% dplyr::collect()
 
     # Update the table with the same data again update_snapshot() and store the results
-    update_snapshot(.data, conn, db_table, "2022-10-04 09:00:00", logger = create_logger("2022-10-04 09:00:00"))
+    update_snapshot(.data, conn, db_table, "2022-10-04 09:00:00", logger = logger)
     target_data_2 <- get_table(conn, db_table, slice_ts = NULL) %>% dplyr::collect()
 
     # Check that the two updates are identical
@@ -480,7 +528,6 @@ test_that("update_snapshot() works with Id objects", {
     target_table <- id("test.mtcars_modified", conn)
 
     logger <- Logger$new(output_to_console = FALSE,
-                         timestamp = Sys.time(),
                          db_table = "test.mtcars_modified",
                          log_conn = NULL,
                          log_table_id = NULL,
